@@ -4,6 +4,7 @@ import pandas as pd
 import time
 import zipfile
 import os
+import copy
 import logging
 import json
 
@@ -35,7 +36,7 @@ class ModelFramework:
         logger.debug("ModelFramework.__init__")
         self.uid = str(uuid.uuid4())
 
-        for i in ["learner", "validation"]:  # mandatory parameters
+        for i in ["learner", "validation_strategy"]:  # mandatory parameters
             if i not in params:
                 msg = "Missing {0} parameter in ModelFramework params".format(i)
                 logger.error(msg)
@@ -47,7 +48,7 @@ class ModelFramework:
         self._name = params.get("name", "model")
         self.additional_params = params.get("additional")
         self.preprocessing_params = params.get("preprocessing")
-        self.validation_params = params.get("validation")
+        self.validation_params = params.get("validation_strategy")
         self.learner_params = params.get("learner")
 
         self._ml_task = params.get("ml_task")
@@ -129,7 +130,9 @@ class ModelFramework:
             )
 
             self.learner_params["explain_level"] = self._explain_level
-            self.learners += [AlgorithmFactory.get_algorithm(self.learner_params)]
+            self.learners += [
+                AlgorithmFactory.get_algorithm(copy.deepcopy(self.learner_params))
+            ]
             learner = self.learners[-1]
 
             self.callbacks.add_and_set_learner(learner)
@@ -175,10 +178,19 @@ class ModelFramework:
                 explain_level=self._explain_level,
             )
 
+            # save learner and free the memory
+            p = os.path.join(
+                model_path, f"learner_{k_fold+1}.{learner.file_extension()}"
+            )
+            learner.save(p)
+            del learner.model
+            learner.model = None
+            # end of learner training
+
         # end of validation loop
         self.callbacks.on_framework_train_end()
-        self.train_time = time.time() - start_time
         self.get_additional_metrics()
+        self.train_time = time.time() - start_time
         logger.debug("ModelFramework end of training")
 
     def get_metric_name(self):
@@ -232,12 +244,16 @@ class ModelFramework:
     """
 
     def get_type(self):
-        prefix = ""  # "Stacked" if self._is_stacked else ""
-        return prefix + self.learner_params.get("model_type")
+        return self.learner_params.get("model_type")
 
     def get_name(self):
         return self._name
 
+    def is_valid(self):
+        """ is_valid is used in Ensemble to check if it has more than 1 model in it.
+            If Ensemble has only 1 model in it, then Ensemble shouldn't be used as best model """
+        return True
+
     def predict(self, X):
         logger.debug("ModelFramework.predict")
 
@@ -249,7 +265,6 @@ class ModelFramework:
             # preprocessing goes here
             X_data, _ = self.preprocessings[ind].transform(X.copy(), None)
             y_p = learner.predict(X_data)
-
             y_p = self.preprocessings[ind].inverse_scale_target(y_p)
 
             y_predicted = y_p if y_predicted is None else y_predicted + y_p
@@ -289,6 +304,7 @@ class ModelFramework:
         return self._additional_metrics
 
     def save(self, model_path):
+        start_time = time.time()
         logger.info(f"Save the model {model_path}")
 
         type_of_predictions = (
@@ -303,7 +319,7 @@ class ModelFramework:
         saved = []
         for i, l in enumerate(self.learners):
             p = os.path.join(model_path, f"learner_{i+1}.{l.file_extension()}")
-            l.save(p)
+            # l.save(p)
             saved += [p]
 
         with open(os.path.join(model_path, "framework.json"), "w") as fout:
@@ -341,6 +357,9 @@ class ModelFramework:
 
         with open(os.path.join(model_path, "status.txt"), "w") as fout:
             fout.write("ALL OK!")
+        # I'm adding save time to total train time
+        # there is always save after the training
+        self.train_time += time.time() - start_time
 
     def model_markdown(self):
         long_name = AlgorithmsRegistry.get_long_name(
