@@ -123,7 +123,7 @@ class AdditionalMetrics:
             "metric_details": pd.DataFrame(details),
             "max_metrics": pd.DataFrame(max_metrics),
             "confusion_matrix": conf_matrix,
-            "threshold": float(max_metrics["f1"]["threshold"]),
+            "threshold": float(max_metrics["accuracy"]["threshold"]),
         }
 
     @staticmethod
@@ -147,6 +147,9 @@ class AdditionalMetrics:
 
         # Print the confusion matrix
         predictions = predictions["label"]
+        if not pd.api.types.is_string_dtype(predictions):
+            predictions = predictions.astype(str)
+
         if not pd.api.types.is_string_dtype(target):
             target = target.astype(str)
 
